.. project-template documentation master file, created by
   sphinx-quickstart on Mon Jan 18 14:44:12 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##################################
Welcome to seglearn documentation!
##################################

This project is an sklearn extension for machine learning time series or sequences. It provides an integrated pipeline for segmentation, feature extraction, feature processing, and a final estimator compatible with sklearn model evaluation and parameter optimization tools. Seglearn provides a flexible approach to multivariate time series and contextual data for classification, regression, and forecasting problems. Support and examples are provided for learning time series with classical machine learning and deep learning models. 

See the source code repository on github: https://github.com/dmbee/seglearn


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Getting Started

   install

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation

   user_guide
   api
   change_log


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Tutorial - Examples

   auto_examples/index

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Addtional Information

   authors
   citations


`Getting started <install.html>`_
---------------------------------

Information to install, test, and contribute to the package.

`User Guide <user_guide.html>`_
-------------------------------

The main documentation. This contains an in-depth description of all
algorithms and how to apply them.

`API Documentation <api.html>`_
-------------------------------

The exact API of all functions and classes, as given in the
docstring. The API documents expected types and allowed features for
all functions, and all parameters available for the algorithms.

`Examples <auto_examples/index.html>`_
--------------------------------------

A set of examples illustrating the use of the different algorithms. It
complements the `User Guide <user_guide.html>`_.

`Authors <authors.html>`_
-------------------------

`Citing Seglearn <citations.html>`_
-------------------------

`Change Log <change_log.html>`_
-------------------------------


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

